C     -*- fortran -*-
C     This file is autogenerated with f2py (version:2)
C     It contains Fortran 77 wrappers to fortran functions.

      subroutine f2pywraparclen (arclenf2pywrap, p, q)
      external arclen
      real p(3)
      real q(3)
      real arclenf2pywrap, arclen
      arclenf2pywrap = arclen(p, q)
      end

